"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const foundation_low_1 = require("foundation-low");
class FirebaseBase {
    constructor(options) {
        this.db = options.db;
    }
    collection(name) {
        this.chain = this.db.collection(name);
        return this;
    }
    doc(ref) {
        this.chain = this.chain.doc(ref);
        return this;
    }
    async get() {
        const snapshot = await this.chain.get();
        return this.getDataFromSnapshot(snapshot);
    }
    getDataFromSnapshot(snapshot) {
        if (snapshot.data) {
            if (!snapshot.exists) {
                return undefined;
            }
            return {
                id: snapshot.id,
                ...snapshot.data()
            };
        }
        const docs = [];
        snapshot.forEach((doc) => {
            docs.push({
                id: doc.id,
                ...doc.data()
            });
        });
        return docs;
    }
    where(query) {
        foundation_low_1.forOwn(query, (value, key) => {
            switch (true) {
                case Array.isArray(value):
                    this.chain = this.chain.where(key, value[0], value[1]);
                    break;
                default:
                    this.chain = this.chain.where(key, "==", value);
                    break;
            }
        });
        return this;
    }
    limit(amount) {
        this.chain = this.chain.limit(amount);
        return this;
    }
    orderBy(order) {
        this.chain = this.chain.orderBy(order);
        return this;
    }
}
exports.default = FirebaseBase;
//# sourceMappingURL=FirebaseBase.js.map